# emoji-data

[![CircleCI](https://circleci.com/gh/tanbro/emoji-data.svg?style=svg)](https://circleci.com/gh/tanbro/emoji-data)
[![Documentation Status](https://readthedocs.org/projects/emoji-data/badge/?version=latest)](https://emoji-data.readthedocs.io/en/latest/?badge=latest)

A small library, it does:

- Load `Emoji` data from the data file defined by [Unicode® Emoji](https://unicode.org/emoji/charts/index.html).
- Provide a class holding the data, and representing `Emoji` characters.
- Regular Express for `Emoji` characters
